require 'open3'
require 'wdi_tf/main'

module WdiTf
	class Main
        def clean_workspace
            verbose("Cleaning workspace.")
            
            Dir["*.tf"].each do |file|
                if File.symlink?(file)
                    verbose("  removing #{ file }")
                    File.delete(file)
                end
            end
        end
        
        def generate_vars_file(file:, vars:)
            if vars.length > 0
                verbose("Generate the #{ file } file from Terraform.proj information.")
                
                open(file, 'w') do |f|
                    vars.each do |var, val|
                        verbose("  #{ var } = \"#{ val }\"")
                        f.puts "#{ var } = \"#{ val }\""
                    end
                end
            elsif File.exists?(file)
                File.delete(file)
            end
        end
        
        def build_workspace(files:)
            verbose("Building workspace.")
            
            files.each do |d_file, s_file|
                verbose("  symlinking #{ s_file }")
                File.symlink(s_file, d_file)
            end
        end
        
        def run_terraform(command:, variables:)
            info("Running Terraform command.")
            
            cmd = "terraform init && terraform #{ command }"
            
            if File.exists?(variables)
                cmd = "#{ cmd } -var-file=#{ variables }"
            end
            
            if command == 'apply'
                cmd = "#{ cmd } -auto-approve"
            end
            
            if command == 'destroy'
                cmd = "#{ cmd } -force"
            end
            
            info("  #{ cmd }")
            Open3.popen2e(cmd) do |stdin, stdout_err, wait_thr|
                while line = stdout_err.gets
                    puts line
                end
                
                exit_status = wait_thr.value
                
                unless exit_status.success?
                    abort "FAILED !!! #{cmd}"
                end
            end
        end
	end
end
